"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Form = Form;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _formHelpers = require("./form-helpers");

var _FormActions = require("./FormActions");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function Form(_ref) {
  var children = _ref.children,
      initialValues = _ref.initialValues,
      onSubmit = _ref.onSubmit,
      submitLabel = _ref.submitLabel,
      cancelLabel = _ref.cancelLabel,
      onCancel = _ref.onCancel;
  var formState = (0, _formHelpers.useForm)(initialValues);

  function handleSubmit(e) {
    e.preventDefault();
    var res = onSubmit(formState.getFormData(), function () {
      return formState.reset();
    });

    if (res && res.then) {
      res.then(function () {
        formState.reset();
      });
    }
  }

  function handleCancel() {
    //TODO: improve cancel options
    onCancel();
  }

  return _react["default"].createElement("form", {
    onSubmit: handleSubmit
  }, _react["default"].createElement(_formHelpers.FormContext.Provider, {
    value: formState
  }, children), _react["default"].createElement(_FormActions.FormActions, {
    submitLabel: submitLabel,
    cancelLabel: cancelLabel,
    onCancel: handleCancel
  }));
}

Form.defaultProps = {
  submitLabel: 'Submit',
  cancelLabel: 'Cancel'
};
Form.propTypes = {
  submitLabel: _propTypes["default"].string,
  onSubmit: _propTypes["default"].func.isRequired,
  cancelLabel: _propTypes["default"].string,
  onCancel: _propTypes["default"].func.isRequired,
  children: _propTypes["default"].oneOfType([_propTypes["default"].element, _propTypes["default"].arrayOf(_propTypes["default"].element)]),
  initialValues: _propTypes["default"].object
};