"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.TableBody = TableBody;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _tableHelpers = require("./table-helpers");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function TableBody(_ref) {
  var columns = _ref.columns,
      docs = _ref.docs,
      rowClass = _ref.rowClass,
      actions = _ref.actions;
  return _react["default"].createElement("tbody", null, docs.map(function (doc, docIndex) {
    return _react["default"].createElement("tr", {
      key: docIndex,
      className: rowClass(doc)
    }, columns.map(function (column, columnIndex) {
      return _react["default"].createElement("td", {
        key: columnIndex,
        className: (0, _tableHelpers.getColumnClass)(column)
      }, getColumnValue(doc, column, docIndex));
    }), actions && _react["default"].createElement("td", {
      className: "text-center"
    }, actions.map(function (action, actionIndex) {
      return _react["default"].createElement("a", _extends({
        key: actionIndex,
        title: action.title
      }, getActionProps(action, doc), {
        className: actionIndex > 0 ? 'ml-2' : ''
      }), action.content);
    })));
  }));
}

TableBody.propTypes = {
  actions: _propTypes["default"].arrayOf(_propTypes["default"].object),
  columns: _propTypes["default"].arrayOf(_propTypes["default"].oneOfType([_propTypes["default"].string, _propTypes["default"].object])),
  docs: _propTypes["default"].arrayOf(_propTypes["default"].object),
  rowClass: _propTypes["default"].func
};

function getColumnValue(doc, column, docIndex) {
  var rawValue = doc[column.attribute];

  if (!column.format) {
    return rawValue;
  }

  return column.format(rawValue, doc, docIndex);
}

function getActionProps(action, doc) {
  var props = {};

  if (action.onClick) {
    props.href = '';

    props.onClick = function (e) {
      e.stopPropagation();
      e.preventDefault();
      action.onClick(doc);
    };
  } else if (action.link) {
    props.href = action.link(doc);
  }

  return props;
}