'use strict';

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance"); }

function _iterableToArrayLimit(arr, i) { if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) { return; } var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function splitPath(path) {
  return path.split(/[.[]/).map(function (s) {
    return s.replace(']', '');
  });
}

function getValue(doc, path, formatter) {
  var paths = splitPath(path);
  var value = paths.reduce(function (acc, attr) {
    if (!acc) {
      return;
    }

    return acc[attr];
  }, doc);
  return formatter ? formatter(value, doc) : value;
}

function setValue(doc, path, value) {
  var paths = splitPath(path);

  if (paths.length === 1) {
    doc[path] = value;
    return;
  }

  var lastPath = paths[paths.length - 1];
  var remainingPaths = paths.slice(0, paths.length - 1);
  var obj = remainingPaths.reduce(function (acc, attr) {
    if (!attr) {
      return acc;
    }

    if (!acc[attr]) {
      acc[attr] = {};
    }

    return acc[attr];
  }, doc);
  obj[lastPath] = value;
}

function serialize(value) {
  if (_typeof(value) !== 'object' || Boolean(value.props)) {
    return value;
  }

  return JSON.stringify(value);
}

function removeEmptyFields(obj) {
  return Object.entries(obj).reduce(function (acc, _ref) {
    var _ref2 = _slicedToArray(_ref, 2),
        key = _ref2[0],
        value = _ref2[1];

    if (value) {
      acc[key] = value;
    }

    return acc;
  }, {});
}

function flattenObject(obj) {
  var prefix = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '';
  var ignoreArrays = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
  return Object.entries(obj).reduce(function (acc, _ref3) {
    var _ref4 = _slicedToArray(_ref3, 2),
        key = _ref4[0],
        value = _ref4[1];

    if (ignoreArrays && Array.isArray(value)) {
      return _objectSpread({}, acc, _defineProperty({}, key, value));
    }

    var prefixedKey = "".concat(prefix ? "".concat(prefix, ".") : '').concat(key);

    if (_typeof(value) !== 'object') {
      acc[prefixedKey] = value;
      return acc;
    }

    return _objectSpread({}, acc, {}, flattenObject(value, prefixedKey, ignoreArrays));
  }, {});
}

function inflateObject(obj) {
  return Object.entries(obj).reduce(function (acc, _ref5) {
    var _ref6 = _slicedToArray(_ref5, 2),
        key = _ref6[0],
        value = _ref6[1];

    setValue(acc, key, value);
    return acc;
  }, {});
}

module.exports = {
  flattenObject: flattenObject,
  getValue: getValue,
  inflateObject: inflateObject,
  removeEmptyFields: removeEmptyFields,
  serialize: serialize,
  setValue: setValue
};