'use strict';

function splitPath(path) {
  return path.split(/[.[]/).map((s) => s.replace(']', ''));
}

function getValue(doc, path, formatter) {
  const paths = splitPath(path);

  const value = paths.reduce((acc, attr) => {
    if (!acc) {
      return;
    }

    return acc[attr];
  }, doc);

  return formatter ? formatter(value, doc) : value;
}

function setValue(doc, path, value) {
  const paths = splitPath(path);

  if (paths.length === 1) {
    doc[path] = value;

    return;
  }

  const lastPath = paths[paths.length - 1];
  const remainingPaths = paths.slice(0, paths.length - 1);

  const obj = remainingPaths.reduce((acc, attr) => {
    if (!attr) {
      return acc;
    }

    if (!acc[attr]) {
      acc[attr] = {};
    }

    return acc[attr];
  }, doc);

  obj[lastPath] = value;
}

function serialize(value) {
  if (typeof value !== 'object' || Boolean(value.props)) {
    return value;
  }

  return JSON.stringify(value);
}

function removeEmptyFields(obj) {
  return Object.entries(obj).reduce((acc, [key, value]) => {
    if (value) {
      acc[key] = value;
    }

    return acc;
  }, {});
}

function flattenObject(obj, prefix = '', ignoreArrays = false) {
  return Object.entries(obj).reduce((acc, [key, value]) => {
    if (ignoreArrays && Array.isArray(value)) {
      return {
        ...acc,
        [key]: value,
      };
    }

    const prefixedKey = `${prefix ? `${prefix}.` : ''}${key}`;

    if (typeof value !== 'object') {
      acc[prefixedKey] = value;

      return acc;
    }

    return {
      ...acc,
      ...flattenObject(value, prefixedKey, ignoreArrays),
    };
  }, {});
}

function inflateObject(obj) {
  return Object.entries(obj).reduce((acc, [key, value]) => {
    setValue(acc, key, value);

    return acc;
  }, {});
}

module.exports = {
  flattenObject,
  getValue,
  inflateObject,
  removeEmptyFields,
  serialize,
  setValue,
};
